@@ -22,19 +22,7 @@
 # along with this program.  A copy can be cound in the R installation
 # directory under \share\licenses. If not, see http://www.gnu.org/licenses/.
 
-.First.lib <- function(libname, pkgname) {
-   # require(Hmisc)
-   require(xpose4data)
-   require(xpose4generic)
-   require(xpose4specific)
-   require(xpose4classic)
+.onLoad <- function(libname, pkgname) {
+    createXposeClasses()
+    create.xpose.plot.classes()
 }
-
-#.onLoad <- function(libname, pkgname) {
-#   createXposeClasses()
-#   if (!(pmatch("Hmisc", installed.packages()) > 0)) {
-#     install.packages("Hmisc", dependencies = TRUE)
-#   }
-#}
-
-
